@@ -6,7 +6,7 @@
 #' @param conf_level A number specifying the confidence level. By default 0.95.
 #' @param estimate The function to use to calculate the estimate.
 #' @param ... Unused
-#' @return An tibble of the coefficients with the columns indicating the
+#' @return An data frame of the coefficients with the columns indicating the
 #' \code{term}, \code{estimate}, standard deviation (\code{sd}), \code{zscore},
 #' \code{lower} and \code{upper} credible intervals and \code{pvalue}.
 #' @export
@@ -29,11 +29,11 @@ coef.numeric <- function(object, conf_level = 0.95, estimate = stats::median, ..
   if (anyNA(object) || identical(length(object), 1L)) quantiles[c(1,2)] <- NA
 
   estimate <- estimate(object)
-  if(!identical(length(estimate), 1L)) error("function estimate must return a scalar")
+  if(!identical(length(estimate), 1L)) err("function estimate must return a scalar")
   sd <- stats::sd(object)
   zscore = mean(object) / sd
 
-  tibble::tibble(estimate = estimate, sd = sd, zscore = zscore,
+  tibble(estimate = estimate, sd = sd, zscore = zscore,
     lower = quantiles[1], upper = quantiles[2], pvalue = pvalue(object))
 }
 
