@@ -8,16 +8,12 @@
 #'
 #' @references
 #' Brooks, S., Gelman, A., Jones, G.L., and Meng, X.-L. (Editors). 2011. Handbook for Markov Chain Monte Carlo. Taylor & Francis, Boca Raton.
-#'
-#' @param x An MCMC object
-#' @param by A string indicating whether to return the estimates by
-#' the object ("all"), "parameter" or "term"
-#' @param as_df A flag indicating whether to return the estimates as a data frame versus a list.
-#' @param ... Unused
+#' @inheritParams rhat
 #' @return The esr value(s) as a data frame or list
 #' @export
 #' @examples
 #' esr(mcmcr_example)
+#' esr(mcmcrs(mcmcr_example, mcmcr_example))
 esr <- function(x, ...) {
   UseMethod("esr")
 }
@@ -70,6 +66,8 @@ esr.mcmcr <- function(x, by = "all", as_df = FALSE, ...) {
 
 #' @describeIn esr Effective Sampling Rate for an mcmcrs object
 #' @export
-esr.mcmcrs <- function(x, by = "all", ...) {
-  lapply(x, esr, by = by)
+esr.mcmcrs <- function(x, by = "all", as_df = FALSE, ...) {
+  check_unused(...)
+
+  lapply(x, esr, by = by, as_df = as_df)
 }
