@@ -4,8 +4,8 @@ test_that("anyNA false", {
   expect_false(anyNA(mcmcr_example))
   expect_false(anyNA(mcmcr_example[[1]]))
   expect_false(anyNA(mcmcrs(mcmcr_example, mcmcr_example)))
-  expect_false(anyNA(coda::as.mcmc.list(mcmcr_example)))
-  expect_false(anyNA(coda::as.mcmc.list(mcmcr_example)[[1]]))
+  expect_false(anyNA(as.mcmc.list(mcmcr_example)))
+  expect_false(anyNA(as.mcmc.list(mcmcr_example)[[1]]))
 })
 
 test_that("anyNA true", {
@@ -13,6 +13,6 @@ test_that("anyNA true", {
   expect_true(anyNA(mcmcr_example))
   expect_true(anyNA(mcmcr_example[[1]]))
   expect_true(anyNA(mcmcrs(mcmcr_example, mcmcr_example)))
-  expect_true(anyNA(coda::as.mcmc.list(mcmcr_example)))
-  expect_true(anyNA(coda::as.mcmc.list(mcmcr_example)[[1]]))
+  expect_true(anyNA(as.mcmc.list(mcmcr_example)))
+  expect_true(anyNA(as.mcmc.list(mcmcr_example)[[1]]))
 })
