@@ -8,9 +8,9 @@ test_that("estimates", {
 })
 
 test_that("estimates not as list", {
-  expect_equal(estimates(mcmcr_example[[1]], as_df = TRUE), tibble::tibble(term = as.term(c("parameter[1]", "parameter[2]")), estimate = estimates(mcmcr_example[[1]])))
-  expect_equal(estimates(mcmcr_example[[2]], as_df = TRUE), tibble::tibble(term = as.term(c("parameter[1,1]", "parameter[2,1]", "parameter[1,2]", "parameter[2,2]")), estimate = as.vector(estimates(mcmcr_example[[2]]))))
-  expect_equivalent(estimates(mcmcr_example[[3]], as_df = TRUE), tibble::tibble(term = as.term("parameter"), estimate = estimates(mcmcr_example[[3]])))
+  expect_equal(estimates(mcmcr_example[[1]], as_df = TRUE), tibble(term = as.term(c("parameter[1]", "parameter[2]")), estimate = estimates(mcmcr_example[[1]])))
+  expect_equal(estimates(mcmcr_example[[2]], as_df = TRUE), tibble(term = as.term(c("parameter[1,1]", "parameter[2,1]", "parameter[1,2]", "parameter[2,2]")), estimate = as.vector(estimates(mcmcr_example[[2]]))))
+  expect_equivalent(estimates(mcmcr_example[[3]], as_df = TRUE), tibble(term = as.term("parameter"), estimate = estimates(mcmcr_example[[3]])))
   expect_identical(sort(estimates(mcmcr_example, as_df = TRUE)$term), sort(as.term(c("alpha[1]", "alpha[2]", "beta[1,1]", "beta[2,1]", "beta[1,2]", "beta[2,2]", "sigma"))))
 })
 
